Crate namada_apps_lib

Crate namada_apps_lib 

Shared code for the Namada apps.

Re-exports

pub use tendermint_config;
pub use tendermint_rpc;

Modules

account
Support for signature based authorization of actions on a user account using public key(s) and signature threshold (minimum number of signatures needed to authorize an action) stored on-chain.
address
Implements transparent addresses as described in Accounts Addresses.
args
Structures encapsulating SDK arguments
arith
Arithmetics helpers
bip39
This is a Rust implementation of the bip39 standard for Bitcoin HD wallet mnemonic phrases.
booleans
Boolean related functionality.
borsh
Borsh binary encoding (re-exported) from official crate with custom ext.
bytes
Bytes hex formatting
chain
Chain related data types
cli
The CLI commands that are re-used between the executables namada, namada-node and namada-client.
client
collections
Re-exports of collection types.
config
Node and client configuration
control_flow
Control flow utilities.
dec
A non-negative fixed precision decimal type.
error
Generic Error Type for all of the Shared Crate
eth_abi
This module defines encoding methods compatible with Ethereum smart contracts.
eth_bridge
Ethereum bridge utilities shared between wasm and the cli.
eth_bridge_pool
The necessary type definitions for the contents of the Ethereum bridge pool
ethereum_events
Types representing data intended for Namada via Ethereum events
events
Logic to do with events emitted by the ledger.
gas
Gas accounting module to track the gas usage in a block for transactions and validity predicates triggered by transactions.
governance
Governance library code
hash
Types for working with 32 bytes hashes.
hints
Compiler hints, to improve the performance of certain operations.
ibc
IBC library code
internal
Shared internal types between the host env and guest (wasm).
io
Traits for implementing IO handlers. This is to enable generic IO. The defaults are the obvious Rust native functions.
keccak
This module is for hashing Namada types using the keccak256 hash function in a way that is compatible with smart contracts on Ethereum.
key
Cryptographic keys
logging
A module for anything related to logging
masp
MASP verification wrappers.
masp_primitives
General MASP primitives.
masp_proofs
MASP circuits and proofs.
migrations
parameters
Protocol parameters
proof_of_stake
Proof of Stake system.
queries
Ledger read-only queries can be handled and dispatched via the RPC defined via router! macro.
rpc
SDK RPC queries
signing
Functions to sign transactions
state
Ledger’s state storage with key-value backed store and a merkle tree
string_encoding
Namada’s standard string encoding for public types.
task_env
Functionality to abstract spawning tasks onto a thread pool.
tendermint
Re-export of tendermint v0.37
tendermint_node
tendermint_proto
Re-export of tendermint-proto v0.37
tendermint_rpc
Tendermint RPC definitions and types.
time
Types for dealing with time and durations.
token
Namada transparent and shielded token types, storage keys and storage fns.
tx
SDK functions to construct different types of transactions
uint
An unsigned 256 integer type. Used for, among other things, the backing type of token amounts.
validity_predicate
Types that are used in validity predicates.
voting_power
This module contains types related with validator voting power calculations.
wallet
wasm_loader
A module for loading WASM files and downloading pre-built WASMs.

Macros

impl_display_and_from_str_via_format
Implement std::fmt::Display and std::str::FromStr via Format.
router
Compile time tree patterns router with type-safe dynamic parameter parsing, automatic routing, type-safe path constructors and optional client query methods.
wrap

Structs

ExtendedSpendingKey
Wrapper for masp_primitive’s ExtendedSpendingKey
ExtendedViewingKey
Wrapper for masp_primitive’s FullViewingKey
NamadaImpl
Provides convenience methods for common Namada interactions
PaymentAddress
Wrapper for masp_primitive’s PaymentAddress
ShieldedWallet
Represents the current state of the shielded pool from the perspective of the chosen viewing keys.

Enums

DecodeError
TransferSource
Represents a source of funds for a transfer
TransferTarget
Represents a target for the funds of a transfer

Constants

DEFAULT_GAS_LIMIT
Default gas-limit

Traits

MaybeSend
MaybeSync
Namada
An interface for high-level interaction with the Namada SDK
ShieldedUtils
Abstracts platform specific details away from the logic of shielded pool operations.

Functions

consensus_version
Get the current consensus version
decode
Decode a value with borsh
encode
Encode a value with borsh