Module context

Module context 

CLI input types can be used for command arguments

Structs

AddrOrNativeToken
Address that defaults to the native token address.
ChainContext
Command execution context with chain-specific data
Context
Command execution context
FromContext
Argument that can be given raw or found in the Context.

Constants

ENV_VAR_CHAIN_ID
Env. var to read the Namada chain id from
ENV_VAR_WASM_DIR
Env. var to set wasm directory

Traits

ArgFromContext
CLI argument that found via the ChainContext.
ArgFromMutContext
CLI argument that found via the ChainContext and cached (as in case of an encrypted keypair that has been decrypted), hence using mutable context.

Functions

read_or_try_new_global_config
Load global config from expected path in the base_dir or try to generate a new one without a chain if it doesn’t exist.
wasm_dir_from_env_or
Return the wasm artifacts path in use.
wasm_dir_from_env_or_args
Convenience function wrapping over wasm_dir_from_env_or.

Type Aliases

ConfigRpcAddress
RPC address of a locally configured node
WalletAddrOrNativeToken
A raw address (bech32m encoding) or an alias of an address that may be found in the wallet. Defaults to the native token address.
WalletAddress
A raw address (bech32m encoding) or an alias of an address that may be found in the wallet
WalletBalanceOwner
A raw address or a raw full viewing key (bech32m encoding) or an alias of either in the wallet
WalletDatedSpendingKey
A raw dated extended spending key (bech32m encoding) or an alias of an extended spending key in the wallet
WalletDatedViewingKey
A raw full dated viewing key (bech32m encoding) or an alias of a full viewing key in the wallet
WalletKeypair
A raw keypair (hex encoding), an alias, a public key or a public key hash of a keypair that may be found in the wallet
WalletPaymentAddr
A raw payment address (bech32m encoding) or an alias of a payment address in the wallet
WalletPublicKey
A raw public key (hex encoding), a public key hash (also hex encoding) or an alias of an public key that may be found in the wallet
WalletSpendingKey
A raw extended spending key (bech32m encoding) or an alias of an extended spending key in the wallet
WalletTransferSource
A raw address or a raw extended spending key (bech32m encoding) or an alias of either in the wallet
WalletTransferTarget
A raw address or a raw payment address (bech32m encoding) or an alias of either in the wallet
WalletViewingKey
A raw full viewing key (bech32m encoding) or an alias of a full viewing key in the wallet