pub struct OccupiedEntry<'a, K, V> { /* private fields */ }Implementations
Sourceimpl<'a, K, V> OccupiedEntry<'a, K, V>
impl<'a, K, V> OccupiedEntry<'a, K, V>
Sourcepub fn key(&self) -> &K
pub fn key(&self) -> &K
Gets a reference to the entry’s key in the map.
Note that this is not the key that was used to find the entry. There may be an observable
difference if the key type has any distinguishing features outside of Hash and Eq, like
extra fields or the memory address of an allocation.
Sourcepub fn into_mut(self) -> &'a mut V
pub fn into_mut(self) -> &'a mut V
Converts into a mutable reference to the entry’s value in the map, with a lifetime bound to the map itself.
Sourcepub fn insert(&mut self, value: V) -> V
pub fn insert(&mut self, value: V) -> V
Sets the value of the entry to value, and returns the entry’s old value.
Sourcepub fn remove(self) -> V
👎Deprecated: remove disrupts the map order – use swap_remove or shift_remove for explicit behavior.
pub fn remove(self) -> V
remove disrupts the map order – use swap_remove or shift_remove for explicit behavior.Remove the key, value pair stored in the map for this entry, and return the value.
NOTE: This is equivalent to .swap_remove(), replacing this
entry’s position with the last element, and it is deprecated in favor of calling that
explicitly. If you need to preserve the relative order of the keys in the map, use
.shift_remove() instead.
Sourcepub fn swap_remove(self) -> V
pub fn swap_remove(self) -> V
Remove the key, value pair stored in the map for this entry, and return the value.
Like Vec::swap_remove, the pair is removed by swapping it with
the last element of the map and popping it off.
This perturbs the position of what used to be the last element!
Computes in O(1) time (average).
Sourcepub fn shift_remove(self) -> V
pub fn shift_remove(self) -> V
Remove the key, value pair stored in the map for this entry, and return the value.
Like Vec::remove, the pair is removed by shifting all of the
elements that follow it, preserving their relative order.
This perturbs the index of all of those elements!
Computes in O(n) time (average).
Sourcepub fn remove_entry(self) -> (K, V)
👎Deprecated: remove_entry disrupts the map order – use swap_remove_entry or shift_remove_entry for explicit behavior.
pub fn remove_entry(self) -> (K, V)
remove_entry disrupts the map order – use swap_remove_entry or shift_remove_entry for explicit behavior.Remove and return the key, value pair stored in the map for this entry
NOTE: This is equivalent to .swap_remove_entry(),
replacing this entry’s position with the last element, and it is deprecated in favor of
calling that explicitly. If you need to preserve the relative order of the keys in the map,
use .shift_remove_entry() instead.
Sourcepub fn swap_remove_entry(self) -> (K, V)
pub fn swap_remove_entry(self) -> (K, V)
Remove and return the key, value pair stored in the map for this entry
Like Vec::swap_remove, the pair is removed by swapping it with
the last element of the map and popping it off.
This perturbs the position of what used to be the last element!
Computes in O(1) time (average).
Sourcepub fn shift_remove_entry(self) -> (K, V)
pub fn shift_remove_entry(self) -> (K, V)
Remove and return the key, value pair stored in the map for this entry
Like Vec::remove, the pair is removed by shifting all of the
elements that follow it, preserving their relative order.
This perturbs the index of all of those elements!
Computes in O(n) time (average).
Sourcepub fn move_index(self, to: usize)
pub fn move_index(self, to: usize)
Moves the position of the entry to a new index by shifting all other entries in-between.
This is equivalent to IndexMap::move_index
coming from the current .index().
- If
self.index() < to, the other pairs will shift down while the targeted pair moves up. - If
self.index() > to, the other pairs will shift up while the targeted pair moves down.
Panics if to is out of bounds.
Computes in O(n) time (average).
Sourcepub fn swap_indices(self, other: usize)
pub fn swap_indices(self, other: usize)
Swaps the position of entry with another.
This is equivalent to IndexMap::swap_indices
with the current .index() as one of the two being swapped.
Panics if the other index is out of bounds.
Computes in O(1) time (average).