BaseContract

Struct BaseContract 

pub struct BaseContract {
    pub methods: HashMap<[u8; 4], (String, usize)>,
    /* private fields */
}
A reduced form of Contract which just takes the abi and produces ABI encoded data for its functions.

Fields

methods: HashMap<[u8; 4], (String, usize)>

A mapping from method signature to a name-index pair for accessing functions in the contract ABI. This is used to avoid allocation when searching for matching functions by signature.

Implementations

Source

impl BaseContract

pub fn encode<T>(&self, name: &str, args: T) -> Result<Bytes, AbiError>
where T: Tokenize,

Returns the ABI encoded data for the provided function and arguments

If the function exists multiple times and you want to use one of the overloaded versions, consider using encode_with_selector

pub fn encode_with_selector<T>( &self, signature: [u8; 4], args: T, ) -> Result<Bytes, AbiError>
where T: Tokenize,

Returns the ABI encoded data for the provided function selector and arguments

pub fn decode<D, T>(&self, name: &str, bytes: T) -> Result<D, AbiError>
where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded function arguments with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

pub fn decode_raw<T>( &self, name: &str, bytes: T, ) -> Result<Vec<Token>, AbiError>
where T: AsRef<[u8]>,

Decodes the provided ABI encoded function arguments with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_output<D, T>(&self, name: &str, bytes: T) -> Result<D, AbiError>
where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded function output with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

pub fn decode_output_raw<T>( &self, name: &str, bytes: T, ) -> Result<Vec<Token>, AbiError>
where T: AsRef<[u8]>,

Decodes the provided ABI encoded function output with the selected function name.

If the function exists multiple times and you want to use one of the overloaded versions, consider using decode_with_selector

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_event<D>( &self, name: &str, topics: Vec<H256>, data: Bytes, ) -> Result<D, AbiError>
where D: Detokenize,

Decodes for a given event name, given the log.topics and log.data fields from the transaction receipt

pub fn decode_event_raw( &self, name: &str, topics: Vec<H256>, data: Bytes, ) -> Result<Vec<Token>, AbiError>

Decodes for a given event name, given the log.topics and log.data fields from the transaction receipt

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_with_selector_raw<T>( &self, signature: [u8; 4], bytes: T, ) -> Result<Vec<Token>, AbiError>
where T: AsRef<[u8]>,

Decodes the provided ABI encoded bytes with the selected function selector

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_with_selector<D, T>( &self, signature: [u8; 4], bytes: T, ) -> Result<D, AbiError>
where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded bytes with the selected function selector

pub fn decode_input_raw<T>(&self, bytes: T) -> Result<Vec<Token>, AbiError>
where T: AsRef<[u8]>,

Decodes the provided ABI encoded input bytes

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn decode_input<D, T>(&self, bytes: T) -> Result<D, AbiError>
where D: Detokenize, T: AsRef<[u8]>,

Decodes the provided ABI encoded input bytes

pub fn decode_output_with_selector<D, T>( &self, signature: [u8; 4], bytes: T, ) -> Result<D, AbiError>
where D: Detokenize, T: AsRef<[u8]>,

Decode the provided ABI encoded bytes as the output of the provided function selector

pub fn decode_output_with_selector_raw<T>( &self, signature: [u8; 4], bytes: T, ) -> Result<Vec<Token>, AbiError>
where T: AsRef<[u8]>,

Decodes the provided ABI encoded bytes with the selected function selector

Returns a Token vector, which lets you decode function arguments dynamically without knowing the return type.

pub fn abi(&self) -> &Contract

Returns a reference to the contract’s ABI

pub fn into_contract<B, M>( self, address: H160, client: B, ) -> ContractInstance<B, M>
where B: Borrow<M>, M: Middleware,

Upgrades a BaseContract into a full fledged contract with an address and middleware.