pub struct Event<B, M, D> {
pub filter: Filter,
/* private fields */
}Expand description
Helper for managing the event filter before querying or streaming its logs
Fields
filter: FilterThe event filter’s state
Implementations
Sourceimpl<B, M, D> Event<B, M, D>
impl<B, M, D> Event<B, M, D>
Sourcepub fn from_block<T>(self, block: T) -> Event<B, M, D>where
T: Into<BlockNumber>,
pub fn from_block<T>(self, block: T) -> Event<B, M, D>where
T: Into<BlockNumber>,
Sets the filter’s from block
Sourcepub fn to_block<T>(self, block: T) -> Event<B, M, D>where
T: Into<BlockNumber>,
pub fn to_block<T>(self, block: T) -> Event<B, M, D>where
T: Into<BlockNumber>,
Sets the filter’s to block
Sourcepub fn at_block_hash<T>(self, hash: T) -> Event<B, M, D>
pub fn at_block_hash<T>(self, hash: T) -> Event<B, M, D>
Sets the filter’s blockHash. Setting this will override previously
set from_block and to_block fields.
Sourcepub fn topic0<T>(self, topic: T) -> Event<B, M, D>
pub fn topic0<T>(self, topic: T) -> Event<B, M, D>
Sets the filter’s 0th topic (typically the event name for non-anonymous events)
Sourcepub fn address(self, address: ValueOrArray<H160>) -> Event<B, M, D>
pub fn address(self, address: ValueOrArray<H160>) -> Event<B, M, D>
Sets the filter’s address.
Sourceimpl<B, M, D> Event<B, M, D>
impl<B, M, D> Event<B, M, D>
Sourcepub async fn stream(
&self,
) -> Result<EventStream<'_, FilterWatcher<'_, <M as Middleware>::Provider, Log>, D, ContractError<M>>, ContractError<M>>
pub async fn stream( &self, ) -> Result<EventStream<'_, FilterWatcher<'_, <M as Middleware>::Provider, Log>, D, ContractError<M>>, ContractError<M>>
Turns this event filter into Stream that yields decoded events.
This will first install a new logs filter via eth_newFilter using the configured
filter object. See also FilterWatcher.
Once the filter is created, this will periodically call eth_getFilterChanges to get the
newest logs and decode them.
Note: Compared to Self::subscribe, which is only available on PubsubClients, such
as Websocket, this is a poll-based subscription, as the node does not notify us when a new
matching log is available, instead we have to actively ask for new logs using additional RPC
requests, and this is done on an interval basis.
Example
// The event we want to get
#[derive(Clone, Debug, EthEvent)]
pub struct Approval {
#[ethevent(indexed)]
pub token_owner: Address,
#[ethevent(indexed)]
pub spender: Address,
pub tokens: U256,
}
let ev = contract.event::<Approval>().from_block(1337).to_block(2000);
let mut event_stream = ev.stream().await.unwrap();
while let Some(Ok(approval)) = event_stream.next().await {
let Approval{token_owner,spender,tokens} = approval;
}Sourcepub async fn stream_with_meta(
&self,
) -> Result<EventStream<'_, FilterWatcher<'_, <M as Middleware>::Provider, Log>, (D, LogMeta), ContractError<M>>, ContractError<M>>
pub async fn stream_with_meta( &self, ) -> Result<EventStream<'_, FilterWatcher<'_, <M as Middleware>::Provider, Log>, (D, LogMeta), ContractError<M>>, ContractError<M>>
As Self::stream, but does not discard Log metadata.
Sourceimpl<B, M, D> Event<B, M, D>
impl<B, M, D> Event<B, M, D>
Sourcepub async fn subscribe(
&self,
) -> Result<EventStream<'_, SubscriptionStream<'_, <M as Middleware>::Provider, Log>, D, ContractError<M>>, ContractError<M>>
pub async fn subscribe( &self, ) -> Result<EventStream<'_, SubscriptionStream<'_, <M as Middleware>::Provider, Log>, D, ContractError<M>>, ContractError<M>>
Returns a subscription for the event
See also Self::stream().
Sourcepub async fn subscribe_with_meta(
&self,
) -> Result<EventStream<'_, SubscriptionStream<'_, <M as Middleware>::Provider, Log>, (D, LogMeta), ContractError<M>>, ContractError<M>>
pub async fn subscribe_with_meta( &self, ) -> Result<EventStream<'_, SubscriptionStream<'_, <M as Middleware>::Provider, Log>, (D, LogMeta), ContractError<M>>, ContractError<M>>
As Self::subscribe, but includes event metadata
Sourceimpl<B, M, D> Event<B, M, D>
impl<B, M, D> Event<B, M, D>
Sourcepub async fn query(&self) -> Result<Vec<D>, ContractError<M>>
pub async fn query(&self) -> Result<Vec<D>, ContractError<M>>
Queries the blockchain for the selected filter and returns a vector of matching event logs
Sourcepub async fn query_with_meta(
&self,
) -> Result<Vec<(D, LogMeta)>, ContractError<M>>
pub async fn query_with_meta( &self, ) -> Result<Vec<(D, LogMeta)>, ContractError<M>>
Queries the blockchain for the selected filter and returns a vector of logs along with their metadata