pub struct MaspClientCapabilities(/* private fields */);Expand description
Enumerates the capabilities of a MaspClient implementation.
Implementations
Sourceimpl MaspClientCapabilities
impl MaspClientCapabilities
pub const MAY_FETCH_PRE_BUILT_NOTE_INDEX: MaspClientCapabilities
pub const MAY_FETCH_PRE_BUILT_TREE: MaspClientCapabilities
pub const MAY_FETCH_PRE_BUILT_WITNESS_MAP: MaspClientCapabilities
pub const NONE: MaspClientCapabilities
Sourcepub const fn plus(self, other: MaspClientCapabilities) -> MaspClientCapabilities
pub const fn plus(self, other: MaspClientCapabilities) -> MaspClientCapabilities
Add other to the current set of capabilities.
Sourcepub const fn minus(
self,
other: MaspClientCapabilities,
) -> MaspClientCapabilities
pub const fn minus( self, other: MaspClientCapabilities, ) -> MaspClientCapabilities
Subtract other from the current set of capabilities.
Sourcepub const fn contains(self, other: MaspClientCapabilities) -> bool
pub const fn contains(self, other: MaspClientCapabilities) -> bool
Check if other has a subset of the MaspClientCapabilities of
self.
Sourcepub const fn are_none(self) -> bool
pub const fn are_none(self) -> bool
Check whether there are no MaspClientCapabilities.
Sourcepub const fn may_fetch_pre_built_tree(&self) -> bool
pub const fn may_fetch_pre_built_tree(&self) -> bool
Check if the masp client is able to fetch a pre-built commitment tree.
Sourcepub const fn may_fetch_pre_built_note_index(&self) -> bool
pub const fn may_fetch_pre_built_note_index(&self) -> bool
Check if the masp client is able to fetch a pre-built note index.
Sourcepub const fn may_fetch_pre_built_witness_map(&self) -> bool
pub const fn may_fetch_pre_built_witness_map(&self) -> bool
Check if the masp client is able to fetch a pre-built witness map.