TransferToEthereumStatus

Struct TransferToEthereumStatus 

pub struct TransferToEthereumStatus {
    pub queried_height: BlockHeight,
    pub pending: IndexSet<KeccakHash>,
    pub relayed: IndexSet<KeccakHash>,
    pub expired: IndexSet<KeccakHash>,
    pub unrecognized: IndexSet<KeccakHash>,
}
Container for the status of queried transfers to Ethereum.

Fields

queried_height: BlockHeight

The block height at which the query was performed.

This value may be used to busy wait while a Bridge pool proof is being constructed for it, such that clients can safely perform additional actions.

pending: IndexSet<KeccakHash>

Transfers in the query whose status it was determined to be pending.

relayed: IndexSet<KeccakHash>

Transfers in the query whose status it was determined to be relayed.

expired: IndexSet<KeccakHash>

Transfers in the query whose status it was determined to be expired.

unrecognized: IndexSet<KeccakHash>

Hashes pertaining to bogus data that might have been queried, or transfers that were not in the event log, despite having been relayed to Ethereum or expiring from the Bridge pool.