Hash

Enum Hash 

pub enum Hash {
    Sha256([u8; 32]),
    None,
}
Hash digests

Variants



Sha256([u8; 32])

SHA-256 hashes



None

Empty hash

Implementations

Source

impl Hash

pub fn from_bytes(alg: Algorithm, bytes: &[u8]) -> Result<Hash, Error>

Create a new Hash with the given algorithm type

pub fn from_hex_upper(alg: Algorithm, s: &str) -> Result<Hash, Error>

Decode a Hash from upper-case hexadecimal

pub fn algorithm(self) -> Algorithm

Return the digest algorithm used to produce this hash

pub fn as_bytes(&self) -> &[u8]

Borrow the Hash as a byte slice

pub fn is_empty(&self) -> bool

Convenience function to check for Hash::None