pub struct Subscription { /* private fields */ }Expand description
An interface that can be used to asynchronously receive Events for a
particular subscription.
Examples
use tendermint_rpc::Subscription;
use futures::StreamExt;
/// Prints `count` events from the given subscription.
async fn print_events(subs: &mut Subscription, count: usize) {
let mut counter = 0_usize;
while let Some(res) = subs.next().await {
// Technically, a subscription produces `Result<Event, Error>`
// instances. Errors can be produced by the remote endpoint at any
// time and need to be handled here.
let ev = res.unwrap();
println!("Got incoming event: {:?}", ev);
counter += 1;
if counter >= count {
break
}
}
}Implementations