CLI input types can be used for command arguments
Structs
- Addr
OrNative Token - Address that defaults to the native token address.
- Chain
Context - Command execution context with chain-specific data
- Context
- Command execution context
- From
Context - Argument that can be given raw or found in the
Context.
Constants
- ENV_
VAR_ CHAIN_ ID - Env. var to read the Namada chain id from
- ENV_
VAR_ WASM_ DIR - Env. var to set wasm directory
Traits
- ArgFrom
Context - CLI argument that found via the
ChainContext. - ArgFrom
MutContext - CLI argument that found via the
ChainContextand cached (as in case of an encrypted keypair that has been decrypted), hence using mutable context.
Functions
- read_
or_ try_ new_ global_ config - Load global config from expected path in the
base_diror try to generate a new one without a chain if it doesn’t exist. - wasm_
dir_ from_ env_ or - Return the wasm artifacts path in use.
- wasm_
dir_ from_ env_ or_ args - Convenience function wrapping over
wasm_dir_from_env_or.
Type Aliases
- Config
RpcAddress - RPC address of a locally configured node
- Wallet
Addr OrNative Token - A raw address (bech32m encoding) or an alias of an address that may be found in the wallet. Defaults to the native token address.
- Wallet
Address - A raw address (bech32m encoding) or an alias of an address that may be found in the wallet
- Wallet
Balance Owner - A raw address or a raw full viewing key (bech32m encoding) or an alias of either in the wallet
- Wallet
Dated Spending Key - A raw dated extended spending key (bech32m encoding) or an alias of an extended spending key in the wallet
- Wallet
Dated Viewing Key - A raw full dated viewing key (bech32m encoding) or an alias of a full viewing key in the wallet
- Wallet
Keypair - A raw keypair (hex encoding), an alias, a public key or a public key hash of a keypair that may be found in the wallet
- Wallet
Payment Addr - A raw payment address (bech32m encoding) or an alias of a payment address in the wallet
- Wallet
Public Key - A raw public key (hex encoding), a public key hash (also hex encoding) or an alias of an public key that may be found in the wallet
- Wallet
Spending Key - A raw extended spending key (bech32m encoding) or an alias of an extended spending key in the wallet
- Wallet
Transfer Source - A raw address or a raw extended spending key (bech32m encoding) or an alias of either in the wallet
- Wallet
Transfer Target - A raw address or a raw payment address (bech32m encoding) or an alias of either in the wallet
- Wallet
Viewing Key - A raw full viewing key (bech32m encoding) or an alias of a full viewing key in the wallet