pub struct BlockHeight(/* private fields */);Expand description
This type must be able to represent any valid Ethereum block height. It must also be Borsh serializeable, so that it can be stored in blockchain storage.
In Ethereum, the type for block height is an arbitrary precision integer - see https://github.com/ethereum/go-ethereum/blob/v1.10.26/core/types/block.go#L79.
Implementations
Sourceimpl BlockHeight
impl BlockHeight
Sourcepub fn next(&self) -> BlockHeight
pub fn next(&self) -> BlockHeight
Sourcepub fn unchecked_add(&self, rhs: impl Into<BlockHeight>) -> BlockHeight
pub fn unchecked_add(&self, rhs: impl Into<BlockHeight>) -> BlockHeight
Unchecked epoch addition.
Panic
Panics on overflow. Care must be taken to only use this with trusted values that are known to be in a limited range (e.g. system parameters but not e.g. transaction variables).
Methods from Deref<Target = BUint<bnum::::types::U256::{constant#0}>>
Sourcepub fn bits(&self) -> u32
pub fn bits(&self) -> u32
Returns the smallest number of bits necessary to represent self.
This is equal to the size of the type in bits minus the leading zeros of self.
Examples
use bnum::types::U256;
assert_eq!(U256::from(0b1111001010100u16).bits(), 13);
assert_eq!(U256::ZERO.bits(), 0);Sourcepub fn bit(&self, index: u32) -> bool
pub fn bit(&self, index: u32) -> bool
Returns a boolean representing the bit in the given position (true if the bit is set). The least significant bit is at index 0, the most significant bit is at index Self::BITS - 1
Examples
use bnum::types::U256;
let n = U256::from(0b001010100101010101u32);
assert!(n.bit(0));
assert!(!n.bit(1));
assert!(!n.bit(U256::BITS - 1));Sourcepub fn digits(&self) -> &[u64; N]
pub fn digits(&self) -> &[u64; N]
Returns the digits stored in self as an array. Digits are little endian (least significant digit first).
Sourcepub fn is_zero(&self) -> bool
pub fn is_zero(&self) -> bool
Returns whether self is zero.
Examples
use bnum::types::U256;
assert!(U256::ZERO.is_zero());
assert!(!U256::ONE.is_zero());Sourcepub fn is_one(&self) -> bool
pub fn is_one(&self) -> bool
Returns whether self is one.
Examples
use bnum::types::U256;
assert!(U256::ONE.is_one());
assert!(!U256::MAX.is_one());pub const MIN: BUint<N>
pub const MAX: BUint<N>
pub const BITS: u32
pub const BYTES: u32
pub const ZERO: BUint<N> = Self::MIN
pub const ONE: BUint<N>
pub const TWO: BUint<N>
pub const THREE: BUint<N>
pub const FOUR: BUint<N>
pub const FIVE: BUint<N>
pub const SIX: BUint<N>
pub const SEVEN: BUint<N>
pub const EIGHT: BUint<N>
pub const NINE: BUint<N>
pub const TEN: BUint<N>
Sourcepub fn to_str_radix(&self, radix: u32) -> String
pub fn to_str_radix(&self, radix: u32) -> String
Sourcepub fn to_radix_be(&self, radix: u32) -> Vec<u8> ⓘ
pub fn to_radix_be(&self, radix: u32) -> Vec<u8> ⓘ
Returns the integer in the given base in big-endian digit order.
Panics
This function panics if radix is not in the range from 2 to 256 inclusive.
use bnum::types::U512;
let digits = &[3, 55, 60, 100, 5, 0, 5, 88];
let n = U512::from_radix_be(digits, 120).unwrap();
assert_eq!(n.to_radix_be(120), digits);Sourcepub fn to_radix_le(&self, radix: u32) -> Vec<u8> ⓘ
pub fn to_radix_le(&self, radix: u32) -> Vec<u8> ⓘ
Returns the integer in the given base in little-endian digit order.
Panics
This function panics if radix is not in the range from 2 to 256 inclusive.
use bnum::types::U512;
let digits = &[1, 67, 88, 200, 55, 68, 87, 120, 178];
let n = U512::from_radix_le(digits, 250).unwrap();
assert_eq!(n.to_radix_le(250), digits);Trait Implementations
Sourceimpl BorshDeserialize for BlockHeight
impl BorshDeserialize for BlockHeight
fn deserialize_reader<R>(reader: &mut R) -> Result<BlockHeight, Error>where
R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for BlockHeight
impl BorshSerialize for BlockHeight
Sourceimpl Clone for BlockHeight
impl Clone for BlockHeight
Sourcefn clone(&self) -> BlockHeight
fn clone(&self) -> BlockHeight
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BlockHeight
impl Debug for BlockHeight
Sourceimpl Default for BlockHeight
impl Default for BlockHeight
Sourcefn default() -> BlockHeight
fn default() -> BlockHeight
Sourceimpl Deref for BlockHeight
impl Deref for BlockHeight
Sourceimpl<'de> Deserialize<'de> for BlockHeight
impl<'de> Deserialize<'de> for BlockHeight
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BlockHeight, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BlockHeight, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl Display for BlockHeight
impl Display for BlockHeight
Sourceimpl<'a> From<&'a BlockHeight> for &'a Uint256
impl<'a> From<&'a BlockHeight> for &'a Uint256
Sourcefn from(_: &'a BlockHeight) -> &'a Uint256
fn from(_: &'a BlockHeight) -> &'a Uint256
Sourceimpl From<BlockHeight> for Uint256
impl From<BlockHeight> for Uint256
Sourcefn from(_: BlockHeight) -> Uint256
fn from(_: BlockHeight) -> Uint256
Sourceimpl From<Uint256> for BlockHeight
impl From<Uint256> for BlockHeight
Sourcefn from(value: Uint256) -> BlockHeight
fn from(value: Uint256) -> BlockHeight
Sourceimpl From<u64> for BlockHeight
impl From<u64> for BlockHeight
Sourcefn from(value: u64) -> BlockHeight
fn from(value: u64) -> BlockHeight
Sourceimpl Hash for BlockHeight
impl Hash for BlockHeight
Sourceimpl Ord for BlockHeight
impl Ord for BlockHeight
Sourcefn cmp(&self, other: &BlockHeight) -> Ordering
fn cmp(&self, other: &BlockHeight) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Sourceimpl PartialEq for BlockHeight
impl PartialEq for BlockHeight
Sourceimpl PartialOrd for BlockHeight
impl PartialOrd for BlockHeight
Sourceimpl Serialize for BlockHeight
impl Serialize for BlockHeight
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl Eq for BlockHeight
impl StructuralPartialEq for BlockHeight