pub struct ShieldedWallet<U>where
U: ShieldedUtils,{
pub utils: U,
pub tree: BridgeTree,
pub synced_height: BlockHeight,
pub spents: IndexSet<NotePosition>,
pub pos_map: IndexMap<ViewingKey, BTreeSet<NotePosition>>,
pub nf_map: IndexMap<Nullifier, NotePosition>,
pub note_map: IndexMap<NotePosition, CompactNote>,
pub memo_map: IndexMap<NotePosition, MemoBytes>,
pub asset_types: IndexMap<AssetType, AssetData>,
pub conversions: EpochedConversions,
pub note_index: BTreeMap<MaspIndexedTx, NotePosition>,
pub sync_status: ContextSyncStatus,
}Expand description
Represents the current state of the shielded pool from the perspective of the chosen viewing keys.
Fields
utils: ULocation where this shielded context is saved
tree: BridgeTreeThe commitment tree produced by scanning all transactions in the MASP
synced_height: BlockHeightBlock height to which the wallet has been synced to
spents: IndexSet<NotePosition>The set of note positions that have been spent
pos_map: IndexMap<ViewingKey, BTreeSet<NotePosition>>Maps viewing keys to applicable note positions
The inner set includes notes that have already been spent
nf_map: IndexMap<Nullifier, NotePosition>Maps a nullifier to the note position to which it applies
note_map: IndexMap<NotePosition, CompactNote>Maps note positions to their corresponding notes
memo_map: IndexMap<NotePosition, MemoBytes>Maps note positions to their corresponding memos
asset_types: IndexMap<AssetType, AssetData>Maps asset types to their decodings
conversions: EpochedConversionsA conversions cache
note_index: BTreeMap<MaspIndexedTx, NotePosition>Maps a shielded tx to the index of its first output note.
sync_status: ContextSyncStatusThe sync state of the context
Implementations
Sourceimpl<U> ShieldedWallet<U>
impl<U> ShieldedWallet<U>
Sourcepub async fn load(&mut self)
pub async fn load(&mut self)
Try to load the last saved shielded wallet from the given context directory. If the file is missing, an empty wallet is created. Otherwise, we load the wallet and attempt to migrate it to the latest version. This function panics if that fails.
Sourcepub async fn try_load<F, X>(&mut self, on_error: F)
pub async fn try_load<F, X>(&mut self, on_error: F)
Same as the load function, but is provided an async closure as an error handler. This is useful for calling this function from non-CLI frontends.
Sourcepub async fn load_confirmed(&mut self)
pub async fn load_confirmed(&mut self)
Try to load the last saved confirmed shielded context from the given context directory.If the file is missing, an empty wallet is created. Otherwise, we load the wallet and attempt to migrate it to the latest version. This function panics if that fails.
Sourcepub async fn save(&self) -> Result<(), Error>
pub async fn save(&self) -> Result<(), Error>
Save this shielded context into its associated context directory. If the state to be saved is confirmed than also delete the speculative one (if available)
Sourcepub async fn sync<M, T, I>(
&mut self,
env: impl TaskEnvironment,
config: ShieldedSyncConfig<M, T, I>,
last_query_height: Option<BlockHeight>,
sks: &[DatedKeypair<ExtendedSpendingKey>],
fvks: &[DatedKeypair<ViewingKey>],
) -> Result<(), Report>
pub async fn sync<M, T, I>( &mut self, env: impl TaskEnvironment, config: ShieldedSyncConfig<M, T, I>, last_query_height: Option<BlockHeight>, sks: &[DatedKeypair<ExtendedSpendingKey>], fvks: &[DatedKeypair<ViewingKey>], ) -> Result<(), Report>
Sync the current state of the multi-asset shielded pool in a ShieldedContext with the state on-chain.
pub fn save_decrypted_shielded_outputs( &mut self, vk: &ViewingKey, note_pos: NotePosition, note: Note, pa: PaymentAddress, memo: MemoBytes, ) -> Result<(), Report>
pub fn save_shielded_spends( &mut self, transaction: &Transaction, update_tree: bool, ) -> Result<(), Report>
Sourcepub async fn compute_shielded_balance(
&mut self,
vk: &ViewingKey,
) -> Result<Option<ValueSum<AssetType, i128>>, Report>
pub async fn compute_shielded_balance( &mut self, vk: &ViewingKey, ) -> Result<Option<ValueSum<AssetType, i128>>, Report>
Compute the total unspent notes associated with the viewing key in the context. If the key is not in the context, then we do not know the balance and hence we return None.
Sourcepub async fn pre_cache_transaction(
&mut self,
masp_tx: &Transaction,
) -> Result<(), Report>
pub async fn pre_cache_transaction( &mut self, masp_tx: &Transaction, ) -> Result<(), Report>
Updates the internal state with the data of the newly generated transaction. More specifically invalidate the spent notes, but do not cache the newly produced output descriptions and therefore the merkle tree (this is because we don’t know the exact position in the tree where the new notes will be appended)